@@ -6,22 +6,11 @@ from django.db import models
 from django.contrib.auth.models import User
 from django.contrib.sites.models import Site
 from django.db.models.query import QuerySet
-from utils import update
+from .utils import update
 from django.conf import settings
 from django.utils.functional import cached_property
 from dynamic_preferences.registries import user_preferences_registry, site_preferences_registry, global_preferences_registry
 
-class PreferenceSite(Site):
-
-    class Meta:
-        proxy = True
-        app_label = 'dynamic_preferences'
-
-
-class PreferenceUser(User):
-    class Meta:
-        proxy = True
-        app_label = 'dynamic_preferences'
 
 
 class PreferenceModelManager(models.Manager):
@@ -74,8 +63,8 @@ class BasePreferenceModel(models.Model):
     def __init__(self, *args, **kwargs):
         # Check if the model is already saved in DB
 
-        v = kwargs.pop("value", None)
 
+        v = kwargs.pop("value", None)
         super(BasePreferenceModel, self).__init__(*args, **kwargs)
 
         new = self.pk is None
@@ -152,15 +141,16 @@ user_preferences = UserPreferenceModel.objects
 # Right now, only works if the model is django.contrib.auth.models.User
 # And if settings.CREATE_DEFAULT_PREFERENCES_FOR_NEW_USERS is set to True in settings
 
-create_default_preferencesfor_new_users = getattr(settings, 'CREATE_DEFAULT_PREFERENCES_FOR_NEW_USERS', True)
 from django.db.models.signals import post_save
+from django.contrib.auth.models import User
 
 def create_default_preferences(sender, **kwargs): 
-    # the object which is saved can be accessed via kwargs 'instance' key.
-    obj = kwargs['instance']
-    created = kwargs.get("created")
-    user_preferences_registry.create_default_preferences(obj)
+    create_default_preferencesfor_new_users = getattr(settings, 'CREATE_DEFAULT_PREFERENCES_FOR_NEW_USERS', True)
+    if create_default_preferencesfor_new_users and settings.AUTH_USER_MODEL == "auth.User":
+        # the object which is saved can be accessed via kwargs 'instance' key.
+        obj = kwargs['instance']
+        created = kwargs.get("created")
+        user_preferences_registry.create_default_preferences(obj)
 
-if create_default_preferencesfor_new_users and settings.AUTH_USER_MODEL == "auth.User":
-    from django.contrib.auth.models import User
-    post_save.connect(create_default_preferences, sender=User)
\ No newline at end of file
+
+post_save.connect(create_default_preferences, sender=User)
\ No newline at end of file
