@@ -5,6 +5,15 @@ from django.utils.importlib import import_module
 # import the logging library
 import logging
 
+try:
+    # use Python3 reload
+    from imp import reload
+
+except:
+
+    # we are on Python2
+    pass
+
 # Get an instance of a logger
 logger = logging.getLogger(__name__)
 
@@ -139,11 +148,12 @@ def clear():
     """
     Remove all data from registries
     """
+
     global_preferences_registry.clear()
     site_preferences_registry.clear()
     user_preferences_registry.clear()
 
-def autodiscover(force_reload=True):
+def autodiscover(force_reload=False):
     """
     Populate the registry by iterating through every section declared in :py:const:`settings.INSTALLED_APPS`.
 
@@ -151,35 +161,29 @@ def autodiscover(force_reload=True):
     :type force_reload: bool.
     """
     print('Dynamic-preferences: autodiscovering preferences...')
-    clear()
-    prefix = ""
+    if force_reload:
+        clear()
 
-    try:
-        test = settings.DYNAMIC_PREFERENCES_USE_TEST_PREFERENCES
-        if test:
-            # Import test preferences instead of regular ones
-            prefix = ".tests"
-    except AttributeError, e:
-        pass
 
     for app in settings.INSTALLED_APPS:
         # try to import self.package inside current app
-        package = '{0}{1}.{2}'.format(app, prefix, preferences_package)
-
+        package = '{0}.{1}'.format(app, preferences_package)
         try:
             #print('Dynamic-preferences: importing {0}...'.format(package))
-            mod = import_module(package)
+            module = import_module(package)
+
             if force_reload:
                 # mainly used in tests
-                reload(mod)
+                reload(module)
 
-        except ImportError, e:
+        except ImportError as e:
             pass
             #print('Dynamic-preferences: cannnot import {0}, {1}'.format(package, e))
 
-    global_preferences_registry.populate()
+    
 
 def register(cls):
+    
     instance = cls()
 
     cls.registry.register(name=cls.name, section=cls.section, preference=instance)
