@@ -1,3 +1,7 @@
+from __future__ import unicode_literals
+from six import string_types
+
+
 class SerializationError(Exception):
     pass
 
@@ -89,7 +93,7 @@ class StringSerializer(BaseSerializer):
 
     @classmethod
     def serialize(cls, value, **kwargs):
-        if not isinstance(value, basestring):
+        if not isinstance(value, string_types):
             raise cls.exception("Cannot serialize, value {0} is not a string".format(value))
 
         if kwargs.get("escape_html", False):
@@ -99,7 +103,8 @@ class StringSerializer(BaseSerializer):
 
     @classmethod
     def deserialize(cls, value, **kwargs):
-        if not isinstance(value, basestring):
-            raise cls.exception("Cannot deserialize, value {0} is not a string".format(value))
-
-        return value
\ No newline at end of file
+        """String deserialisation just return the value as a string"""
+        try:
+            return str(value)
+        except:
+            raise cls.exception("Cannot deserialize value {0} tostring".format(value))
\ No newline at end of file
