@@ -1,17 +1,10 @@
 from django.conf.urls import patterns, include, url
 from django.contrib.admin.views.decorators import staff_member_required
 from django.contrib.auth.decorators import login_required
-from dynamic_preferences import views
-from registries import user_preferences_registry, global_preferences_registry
-from forms import GlobalPreferenceForm
+from . import views
+from .registries import user_preferences_registry, global_preferences_registry
+from .forms import GlobalPreferenceForm
 
-from django.conf import settings
-
-test = False
-try:
-    test = settings.TESTING
-except:
-    pass
 
 urlpatterns = patterns('',
 
@@ -34,8 +27,4 @@ urlpatterns = patterns('',
         name="dynamic_preferences.user.section"),
 )
 
-if test:
 
-    urlpatterns += patterns('',
-        url(r'^test/template$',views.RegularTemplateView.as_view(), name="dynamic_preferences.test.templateview"),      
-    )
